@@ -1,6 +1,7 @@
 import os
 import dvc.api
 
+from fsspec import callbacks as fsscb
 
 __all__ = ["DSHalper"]
 
@@ -23,13 +24,19 @@ class DSHalper:
     def get_model_path(self, model: str):
         model_path = os.path.join(self.dataset_path, DSHalper.MODEL_SUBDIR, model)
         if not os.path.isfile(model_path):
-            self.dvc_file_sys.get_file(rpath=DSHalper.MODEL_SUBDIR + "/" + model, lpath=model_path)
+            self.dvc_file_sys.get_file(
+                rpath=DSHalper.MODEL_SUBDIR + "/" + model, 
+                lpath=model_path, 
+                callback=fsscb.TqdmCallback(tqdm_kwargs={"desc": f"{model} model loading"}))
 
         return model_path
 
     def get_dataset_path(self):
         data_path = self.dataset_path
         if not os.path.isdir(data_path):
-            self.dvc_file_sys.get(rpath=DSHalper.DATA_SUBDIR, lpath=data_path, recursive=True)
+            self.dvc_file_sys.get(
+                rpath=DSHalper.DATA_SUBDIR, 
+                lpath=data_path, recursive=True,
+                callback=fsscb.TqdmCallback(tqdm_kwargs={"desc": f"{self.dataset} dataset loading"}))
 
         return data_path
